import theme from './theme'
import css from 'styled-jsx/css'

const GlobalStyle = css.global`
  /* normalize.css is imported in meta.js */

  @import url('https://fonts.googleapis.com/css?family=Roboto+Mono:300|Roboto:300,900&display=swap');

  /* Use border-box sizing instead of context-box.
   This includes border and padding in the calculation.

   Also define a default font. */
  html {
    box-sizing: border-box;
    font-family: 'Roboto', sans-serif;
    font-weight: 300;
    /*font-size: 12px;*/
  }

  *,
  *::before,
  *::after {
    box-sizing: inherit;
  }

  #__next {
    display: grid;
    grid-template-areas:
      'header'
      'main'
      'footer';
    grid-template-rows: auto 1fr minmax(75px, auto);

    min-height: 100vh;

    background: ${theme.colors.offWhite};
    color: ${theme.colors.black};
    box-shadow: ${theme.bs};
  }

  #__next.admin {
    grid-template-areas:
      'header header'
      'sidebar main'
      'footer footer';
  }

  #__next.admin :global(nav.admin-sidebar) {
    grid-area: sidebar;
  }

  header {
    grid-area: header;
  }
  main {
    grid-area: main;
    padding: 1em 0.3em;
  }

  footer {
    grid-area: footer;
  }

  /* Use bold font for headers */
  h1,
  h2,
  h3,
  h4,
  h5,
  h6 {
    font-weight: 900;
    color: ${theme.colors.darkerblue};
  }

  /* Use monospace font for pre */
  pre {
    font-family: 'Roboto Mono', monospace;
  }

  @media (min-width: 480px) {
    main {
      padding: 2em 1em;
    }
  }

  @media (min-width: 1024px) {
    main {
      padding: 2em 3em;
    }
  }

  form label {
    display: none;
  }

  form input,
  form select,
  form textbox {
    display: block;
    width: 100%;
    margin: 0.8em auto;
    padding: 0.3em;
    border: 2px solid ${theme.colors.darkerblue}00;
    color: ${theme.colors.darkerblue};
    background-color: ${theme.colors.darkerblue}27;
    transition: all 250ms ease-in-out;
  }

  form input:focus,
  form select:focus,
  form textbox:focus {
    color: ${theme.colors.blue};
    background-color: ${theme.colors.blue}15;
    border-bottom: 2px solid ${theme.colors.blue}44;
  }

  button {
    display: block;
    margin: 0.8em auto;
    padding: 0.5em 1em;
    border: none;
    background-color: ${theme.colors.darkerblue};
    color: ${theme.colors.offWhite};
  }
`

export default GlobalStyle
